@@ -31,6 +31,9 @@
 
 #include <MauiKit3/FileBrowsing/fmstatic.h>
 #include <MauiKit3/Core/mauiapp.h>
+#include <MauiKit3/FileBrowsing/moduleinfo.h>
+
+#include <taglib/taglib.h>
 
 #include "../vvave_version.h"
 
@@ -78,19 +81,15 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QApplication app(argc, argv);
 #endif
 
-    qDebug() << "APP LOADING SPEED TESTS" << 1;
-
-
 #ifdef Q_OS_ANDROID
     if (!MAUIAndroid::checkRunTimePermissions({"android.permission.WRITE_EXTERNAL_STORAGE"}))
         return -1;
 
-
-    QAndroidJniObject::callStaticMethod<void>(
-        "org/vvave/mediasession/QMediaSessionManager",
-        "startQtAndroidService",
-        "(Landroid/content/Context;)V",
-        QtAndroid::androidActivity().object());
+//    QAndroidJniObject::callStaticMethod<void>(
+//        "org/vvave/mediasession/QMediaSessionManager",
+//        "startQtAndroidService",
+//        "(Landroid/content/Context;)V",
+//        QtAndroid::androidActivity().object());
 #endif
 
     qDebug() << "APP LOADING SPEED TESTS" << 2;
@@ -99,7 +98,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setWindowIcon(QIcon("qrc:/assets/vvave.png"));
 
     KLocalizedString::setApplicationDomain("vvave");
-    KAboutData about(QStringLiteral("vvave"), i18n("Vvave"), VVAVE_VERSION_STRING, i18n("Organize and listen to your music."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())),QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("vvave"),
+                     QStringLiteral("Vvave"),
+                     VVAVE_VERSION_STRING,
+                     i18n("Organize and listen to your music."),
+                     KAboutLicense::LGPL_V3,
+                     i18n("© 2019-2023 Maui Development Team"),
+                     QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor("Camilo Higuita", i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.addAuthor("Will Chen", i18n("Developer"), QStringLiteral("intralexical@gmail.com"));
@@ -110,7 +115,14 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     about.setOrganizationDomain(VVAVE_URI);
     about.setProgramLogo(app.windowIcon());
     about.setDesktopFileName("org.kde.vvave");
-    about.addComponent("TagLib");
+
+    about.addComponent("TagLib",
+                       "",
+                       QString("%1.%2.%3").arg(QString::number(TAGLIB_MAJOR_VERSION),QString::number(TAGLIB_MINOR_VERSION),QString::number(TAGLIB_PATCH_VERSION)),
+                       "https://taglib.org/api/index.html");
+
+    const auto FBData = MauiKitFileBrowsing::aboutData();
+    about.addComponent(FBData.name(), MauiKitFileBrowsing::buildVersion(), FBData.version(), FBData.webAddress());
 
     KAboutData::setApplicationData(about);
 
@@ -186,17 +198,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     qDebug() << "APP LOADING SPEED TESTS" << 4;
 
-
     engine.load(url);
 
     qDebug() << "APP LOADING SPEED TESTS" << 5;
 
-
 #ifdef Q_OS_MACOS
     //	MAUIMacOS::removeTitlebarFromWindow();
 #endif
 
-
-
     return app.exec();
 }
