@@ -13,6 +13,15 @@ public:
     int limit() const;
     void setLimit(int newLimit);
 
+    void componentComplete() override;
+
+public Q_SLOTS:
+    void insert(const QString &playlist);
+
+    void addTrack(const QString &playlist, const QStringList &urls);
+    void removeTrack(const QString &playlist, const QString &url);
+    void removePlaylist(const int &index);
+
 private:
     FMH::MODEL_LIST list;
     void setList();
@@ -24,21 +33,10 @@ private:
 
     int m_limit = 9999;
 
-signals:
+Q_SIGNALS:
     void sortByChanged();
     void fileTagged(QUrl url, QString playlist);
 
     void limitChanged();
-
-public slots:
-    void insert(const QString &playlist);
-
-    void addTrack(const QString &playlist, const QStringList &urls);
-    void removeTrack(const QString &playlist, const QString &url);
-    void removePlaylist(const int &index);
-
-    // QQmlParserStatus interface
-public:
-    void componentComplete() override;
 };
 
